package betterquesting.questing;

import betterquesting.api.questing.IQuest;
import betterquesting.api.questing.IQuestDatabase;
import betterquesting.api2.storage.DBEntry;
import betterquesting.api2.storage.SimpleDatabase;
import java.util.List;
import java.util.UUID;
import javax.annotation.Nullable;
import net.minecraft.nbt.NBTBase;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.nbt.NBTTagList;

/* loaded from: betterquesting_questing.jar:betterquesting/questing/QuestDatabase.class */
public final class QuestDatabase extends SimpleDatabase<IQuest> implements IQuestDatabase {
    public static final QuestDatabase INSTANCE = new QuestDatabase();

    public /* bridge */ /* synthetic */ NBTBase writeToNBT(NBTBase nBTBase, @Nullable List list) {
        return writeToNBT((NBTTagList) nBTBase, (List<Integer>) list);
    }

    public /* bridge */ /* synthetic */ NBTBase writeProgressToNBT(NBTBase nBTBase, List list) {
        return writeProgressToNBT((NBTTagList) nBTBase, (List<UUID>) list);
    }

    public synchronized IQuest createNew(int id) {
        IQuest quest = new QuestInstance();
        if (id >= 0) {
            add(id, quest);
        }
        return quest;
    }

    public synchronized boolean removeID(int id) {
        boolean success = super.removeID(id);
        if (success) {
            for (DBEntry<IQuest> entry : getEntries()) {
                removeReq((IQuest) entry.getValue(), id);
            }
        }
        return success;
    }

    public synchronized boolean removeValue(IQuest value) {
        int id = getID(value);
        if (id < 0) {
            return false;
        }
        boolean success = removeValue(value);
        if (success) {
            for (DBEntry<IQuest> entry : getEntries()) {
                removeReq((IQuest) entry.getValue(), id);
            }
        }
        return success;
    }

    private void removeReq(IQuest quest, int id) {
        int[] orig = quest.getRequirements();
        if (orig.length <= 0) {
            return;
        }
        boolean hasRemoved = false;
        int[] rem = new int[orig.length - 1];
        for (int i = 0; i < orig.length; i++) {
            if (!hasRemoved && orig[i] == id) {
                hasRemoved = true;
            } else if (!hasRemoved && i >= rem.length) {
                break;
            } else {
                rem[!hasRemoved ? i : i - 1] = orig[i];
            }
        }
        if (hasRemoved) {
            quest.setRequirements(rem);
        }
    }

    public synchronized NBTTagList writeToNBT(NBTTagList nbt, @Nullable List<Integer> subset) {
        for (DBEntry<IQuest> entry : getEntries()) {
            if (subset == null || subset.contains(Integer.valueOf(entry.getID()))) {
                NBTTagCompound jq = new NBTTagCompound();
                if (subset == null || !jq.func_82582_d()) {
                    ((IQuest) entry.getValue()).writeToNBT(jq);
                    jq.func_74768_a("questID", entry.getID());
                    nbt.func_74742_a(jq);
                }
            }
        }
        return nbt;
    }

    public synchronized void readFromNBT(NBTTagList nbt, boolean merge) {
        if (!merge) {
            reset();
        }
        for (int i = 0; i < nbt.func_74745_c(); i++) {
            NBTTagCompound qTag = nbt.func_150305_b(i);
            int qID = qTag.func_150297_b("questID", 99) ? qTag.func_74762_e("questID") : -1;
            if (qID >= 0) {
                IQuest quest = (IQuest) getValue(qID);
                (quest != null ? quest : createNew(qID)).readFromNBT(qTag);
            }
        }
    }

    public synchronized NBTTagList writeProgressToNBT(NBTTagList json, List<UUID> users) {
        for (DBEntry<IQuest> entry : getEntries()) {
            NBTTagCompound jq = ((IQuest) entry.getValue()).writeProgressToNBT(new NBTTagCompound(), users);
            jq.func_74768_a("questID", entry.getID());
            json.func_74742_a(jq);
        }
        return json;
    }

    public synchronized void readProgressFromNBT(NBTTagList json, boolean merge) {
        IQuest quest;
        for (int i = 0; i < json.func_74745_c(); i++) {
            NBTTagCompound qTag = json.func_150305_b(i);
            int qID = qTag.func_150297_b("questID", 99) ? qTag.func_74762_e("questID") : -1;
            if (qID >= 0 && (quest = (IQuest) getValue(qID)) != null) {
                quest.readProgressFromNBT(qTag, merge);
            }
        }
    }
}
